@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -218,7 +214,6 @@ public class LocaleNames_si extends OpenListResourceBundle {
             { "FO", "\u0dc6\u0dd0\u0dbb\u0ddd \u0daf\u0dd6\u0db4\u0dad\u0dca" },
             { "Taml", metaValue_ta },
             { "FR", "\u0db4\u0dca\u200d\u0dbb\u0d82\u0dc1\u0dba" },
-            { "root", "\u0dbb\u0dd6\u0da7\u0dca" },
             { "GA", "\u0d9c\u0dd0\u0db6\u0ddc\u0db1\u0dca" },
             { "GB", "\u0d91\u0d9a\u0dca\u0dc3\u0dad\u0dca \u0dbb\u0dcf\u0da2\u0db0\u0dcf\u0db1\u0dd2\u0dba" },
             { "pcm", "\u0db1\u0ddb\u0da2\u0dd3\u0dbb\u0dd2\u0dba\u0db1\u0dca \u0db4\u0dd9\u0db1\u0dca\u0d9c\u0dd2\u0db1\u0dca" },
@@ -243,7 +238,7 @@ public class LocaleNames_si extends OpenListResourceBundle {
             { "ckb", "\u0dc3\u0ddc\u0dbb\u0dcf\u0db1\u0dd2 \u0d9a\u0dd4\u0dbb\u0dca\u0daf\u0dd2\u0dc2\u0dca" },
             { "zxx", "\u0dc0\u0dcf\u0d9c\u0dca \u0dc0\u0dd2\u0daf\u0dca\u200d\u0dba\u0dcf \u0d85\u0db1\u0dca\u0dad\u0dbb\u0dca\u0d9c\u0dad\u0dba\u0d9a\u0dca \u0db1\u0dd0\u0dad" },
             { "de_AT", "\u0d94\u0dc3\u0dca\u0da7\u0dca\u200d\u0dbb\u0dd2\u0dba\u0dcf\u0db1\u0dd4 \u0da2\u0dbb\u0dca\u0db8\u0db1\u0dca" },
-            { "HK", "\u0dc4\u0ddc\u0d82\u0d9a\u0ddc\u0d82 \u0da0\u0dd3\u0db1 \u0dc0\u0dd2\u0dc1\u0dda\u0dc2 \u0db4\u0dbb\u0dd2\u0db4\u0dcf\u0dbd\u0db1 \u0d9a\u0dbd\u0dcf\u0db4\u0dba" },
+            { "HK", "\u0dc4\u0ddc\u0d82\u0d9a\u0ddc\u0d82 \u0dc0\u0dd2\u0dc1\u0dda\u0dc2 \u0db4\u0dbb\u0dd2\u0db4\u0dcf\u0dbd\u0db1 \u0d9a\u0dbd\u0dcf\u0db4\u0dba \u0da0\u0dd3\u0db1\u0dba" },
             { "HM", "\u0dc4\u0dbb\u0dca\u0da9\u0dca \u0daf\u0dd6\u0db4\u0dad \u0dc3\u0dc4 \u0db8\u0dd0\u0d9a\u0dca\u0da9\u0ddc\u0db1\u0dbd\u0dca\u0da9\u0dca \u0daf\u0dd6\u0db4\u0dad\u0dca" },
             { "HN", "\u0dc4\u0ddc\u0db1\u0dca\u0da9\u0dd4\u0dbb\u0dcf\u0dc3\u0dca" },
             { "HR", "\u0d9a\u0dca\u200d\u0dbb\u0ddc\u0d92\u0dc2\u0dd2\u0dba\u0dcf\u0dc0" },
@@ -329,7 +324,7 @@ public class LocaleNames_si extends OpenListResourceBundle {
             { "MM", "\u0db8\u0dd2\u0dba\u0db1\u0dca\u0db8\u0dcf\u0dbb\u0dba (\u0db6\u0dd4\u0dbb\u0dd4\u0db8\u0dba)" },
             { "MN", "\u0db8\u0ddc\u0db1\u0dca\u0d9c\u0ddd\u0dbd\u0dd2\u0dba\u0dcf\u0dc0" },
             { "new", "\u0db1\u0dd9\u0dc0\u0dcf\u0dbb\u0dd2" },
-            { "MO", "\u0db8\u0d9a\u0dcf\u0dc0\u0dd4 \u0d91\u0dc3\u0dca\u0d92\u0d86\u0dbb\u0dca" },
+            { "MO", "\u0db8\u0dd0\u0d9a\u0dcf\u0dc0\u0dd4 \u0dc0\u0dd2\u0dc1\u0dda\u0dc2 \u0db4\u0dbb\u0dd2\u0db4\u0dcf\u0dbd\u0db1 \u0d9a\u0dbd\u0dcf\u0db4\u0dba \u0da0\u0dd3\u0db1\u0dba" },
             { "MP", "\u0d8b\u0dad\u0dd4\u0dbb\u0dd4 \u0db8\u0dbb\u0dd2\u0dba\u0dcf\u0db1\u0dcf \u0daf\u0dd6\u0db4\u0dad\u0dca" },
             { "MQ", "\u0db8\u0dbb\u0dca\u0da7\u0dd2\u0db1\u0dd2\u0d9a\u0dca" },
             { "MR", "\u0db8\u0ddc\u0dbb\u0dd2\u0da7\u0dda\u0db1\u0dd2\u0dba\u0dcf\u0dc0" },
@@ -557,7 +552,7 @@ public class LocaleNames_si extends OpenListResourceBundle {
             { "scn", "\u0dc3\u0dd2\u0dc3\u0dd2\u0dbd\u0dd2\u0dba\u0db1\u0dca" },
             { "aa", "\u0d85\u0dc6\u0dcf\u0dbb\u0dca" },
             { "ab", "\u0d87\u0db6\u0dca\u0d9a\u0dcf\u0dc3\u0dd2\u0dba\u0dcf\u0db1\u0dd4" },
-            { "af", "\u0d85\u0dc6\u0dca\u0dbb\u0dd2\u0d9a\u0dcf\u0db1\u0dca\u0dc3\u0dca" },
+            { "af", "\u0d85\u0dc6\u0dca\u200d\u0dbb\u0dd2\u0d9a\u0dcf\u0db1\u0dca\u0dc3\u0dca" },
             { "ak", "\u0d85\u0d9a\u0dcf\u0db1\u0dca" },
             { "am", "\u0d87\u0db8\u0dca\u0dc4\u0dcf\u0dbb\u0dd2\u0d9a\u0dca" },
             { "Arab", metaValue_ar },
